# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['InstanceSharedIpsArgs', 'InstanceSharedIps']

@pulumi.input_type
class InstanceSharedIpsArgs:
    def __init__(__self__, *,
                 addresses: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 linode_id: pulumi.Input[_builtins.int]):
        """
        The set of arguments for constructing a InstanceSharedIps resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] addresses: The set of IPs to share with the Linode.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to share the IPs to.
        """
        pulumi.set(__self__, "addresses", addresses)
        pulumi.set(__self__, "linode_id", linode_id)

    @_builtins.property
    @pulumi.getter
    def addresses(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        The set of IPs to share with the Linode.
        """
        return pulumi.get(self, "addresses")

    @addresses.setter
    def addresses(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "addresses", value)

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> pulumi.Input[_builtins.int]:
        """
        The ID of the Linode to share the IPs to.
        """
        return pulumi.get(self, "linode_id")

    @linode_id.setter
    def linode_id(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "linode_id", value)


@pulumi.input_type
class _InstanceSharedIpsState:
    def __init__(__self__, *,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 linode_id: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering InstanceSharedIps resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] addresses: The set of IPs to share with the Linode.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to share the IPs to.
        """
        if addresses is not None:
            pulumi.set(__self__, "addresses", addresses)
        if linode_id is not None:
            pulumi.set(__self__, "linode_id", linode_id)

    @_builtins.property
    @pulumi.getter
    def addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The set of IPs to share with the Linode.
        """
        return pulumi.get(self, "addresses")

    @addresses.setter
    def addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "addresses", value)

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the Linode to share the IPs to.
        """
        return pulumi.get(self, "linode_id")

    @linode_id.setter
    def linode_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "linode_id", value)


@pulumi.type_token("linode:index/instanceSharedIps:InstanceSharedIps")
class InstanceSharedIps(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 linode_id: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Manages IPs shared to a Linode instance.
        For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/post-share-ips).

        > **Beta Notice** IPv6 sharing is currently available through early access.
        To use early access resources, the `api_version` provider argument must be set to `v4beta`.
        To learn more, see the early access documentation.

        > **Notice** This resource should only be defined once per-instance and should not be used alongside the `shared_ipv4` field in `Instance`.

        ## Example Usage

        Share in IPv4 address between two instances:

        ```python
        import pulumi
        import pulumi_linode as linode

        # Create a single primary node
        primary_instance = linode.Instance("primary",
            label="node-primary",
            type="g6-nanode-1",
            region="eu-central")
        # Allocate an IP under the primary node
        primary = linode.InstanceIp("primary", linode_id=primary_instance.id)
        # Create a secondary node
        secondary = linode.Instance("secondary",
            label="node-secondary",
            type="g6-nanode-1",
            region="eu-central")
        # Share the IP with the secondary node
        share_primary = linode.InstanceSharedIps("share-primary",
            linode_id=secondary.id,
            addresses=[primary.address])
        ```

        Share an IPv6 address among a primary node and its replicas:

        ```python
        import pulumi
        import pulumi_linode as linode

        # Create a single primary node
        primary = linode.Instance("primary",
            label="node-primary",
            type="g6-nanode-1",
            region="eu-central")
        # Allocate an IPv6 range pointing at the primary node
        range_ipv6_range = linode.Ipv6Range("range",
            prefix_length=64,
            linode_id=primary.id)
        # Share with primary node
        share_primary = linode.InstanceSharedIps("share-primary",
            linode_id=primary.id,
            addresses=[range_ipv6_range.range])
        config = pulumi.Config()
        number_replicas = config.get_float("numberReplicas")
        if number_replicas is None:
            number_replicas = 2
        # Create two secondary nodes
        secondary = []
        for range in [{"value": i} for i in range(0, number_replicas)]:
            secondary.append(linode.Instance(f"secondary-{range['value']}",
                label=f"node-secondary-{range['value']}",
                type="g6-nanode-1",
                region="eu-central"))
        # Share with secondary nodes
        share_secondary = []
        for range in [{"value": i} for i in range(0, number_replicas)]:
            share_secondary.append(linode.InstanceSharedIps(f"share-secondary-{range['value']}",
                linode_id=secondary[range["value"]].id,
                addresses=[range_ipv6_range.range],
                opts = pulumi.ResourceOptions(depends_on=[share_primary])))
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] addresses: The set of IPs to share with the Linode.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to share the IPs to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceSharedIpsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages IPs shared to a Linode instance.
        For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/post-share-ips).

        > **Beta Notice** IPv6 sharing is currently available through early access.
        To use early access resources, the `api_version` provider argument must be set to `v4beta`.
        To learn more, see the early access documentation.

        > **Notice** This resource should only be defined once per-instance and should not be used alongside the `shared_ipv4` field in `Instance`.

        ## Example Usage

        Share in IPv4 address between two instances:

        ```python
        import pulumi
        import pulumi_linode as linode

        # Create a single primary node
        primary_instance = linode.Instance("primary",
            label="node-primary",
            type="g6-nanode-1",
            region="eu-central")
        # Allocate an IP under the primary node
        primary = linode.InstanceIp("primary", linode_id=primary_instance.id)
        # Create a secondary node
        secondary = linode.Instance("secondary",
            label="node-secondary",
            type="g6-nanode-1",
            region="eu-central")
        # Share the IP with the secondary node
        share_primary = linode.InstanceSharedIps("share-primary",
            linode_id=secondary.id,
            addresses=[primary.address])
        ```

        Share an IPv6 address among a primary node and its replicas:

        ```python
        import pulumi
        import pulumi_linode as linode

        # Create a single primary node
        primary = linode.Instance("primary",
            label="node-primary",
            type="g6-nanode-1",
            region="eu-central")
        # Allocate an IPv6 range pointing at the primary node
        range_ipv6_range = linode.Ipv6Range("range",
            prefix_length=64,
            linode_id=primary.id)
        # Share with primary node
        share_primary = linode.InstanceSharedIps("share-primary",
            linode_id=primary.id,
            addresses=[range_ipv6_range.range])
        config = pulumi.Config()
        number_replicas = config.get_float("numberReplicas")
        if number_replicas is None:
            number_replicas = 2
        # Create two secondary nodes
        secondary = []
        for range in [{"value": i} for i in range(0, number_replicas)]:
            secondary.append(linode.Instance(f"secondary-{range['value']}",
                label=f"node-secondary-{range['value']}",
                type="g6-nanode-1",
                region="eu-central"))
        # Share with secondary nodes
        share_secondary = []
        for range in [{"value": i} for i in range(0, number_replicas)]:
            share_secondary.append(linode.InstanceSharedIps(f"share-secondary-{range['value']}",
                linode_id=secondary[range["value"]].id,
                addresses=[range_ipv6_range.range],
                opts = pulumi.ResourceOptions(depends_on=[share_primary])))
        ```

        :param str resource_name: The name of the resource.
        :param InstanceSharedIpsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceSharedIpsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 linode_id: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceSharedIpsArgs.__new__(InstanceSharedIpsArgs)

            if addresses is None and not opts.urn:
                raise TypeError("Missing required property 'addresses'")
            __props__.__dict__["addresses"] = addresses
            if linode_id is None and not opts.urn:
                raise TypeError("Missing required property 'linode_id'")
            __props__.__dict__["linode_id"] = linode_id
        super(InstanceSharedIps, __self__).__init__(
            'linode:index/instanceSharedIps:InstanceSharedIps',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            linode_id: Optional[pulumi.Input[_builtins.int]] = None) -> 'InstanceSharedIps':
        """
        Get an existing InstanceSharedIps resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] addresses: The set of IPs to share with the Linode.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to share the IPs to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceSharedIpsState.__new__(_InstanceSharedIpsState)

        __props__.__dict__["addresses"] = addresses
        __props__.__dict__["linode_id"] = linode_id
        return InstanceSharedIps(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def addresses(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The set of IPs to share with the Linode.
        """
        return pulumi.get(self, "addresses")

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> pulumi.Output[_builtins.int]:
        """
        The ID of the Linode to share the IPs to.
        """
        return pulumi.get(self, "linode_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetVpcIpsResult',
    'AwaitableGetVpcIpsResult',
    'get_vpc_ips',
    'get_vpc_ips_output',
]

@pulumi.output_type
class GetVpcIpsResult:
    """
    A collection of values returned by getVpcIps.
    """
    def __init__(__self__, filters=None, id=None, ipv6=None, vpc_id=None, vpc_ips=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipv6 and not isinstance(ipv6, bool):
            raise TypeError("Expected argument 'ipv6' to be a bool")
        pulumi.set(__self__, "ipv6", ipv6)
        if vpc_id and not isinstance(vpc_id, int):
            raise TypeError("Expected argument 'vpc_id' to be a int")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_ips and not isinstance(vpc_ips, list):
            raise TypeError("Expected argument 'vpc_ips' to be a list")
        pulumi.set(__self__, "vpc_ips", vpc_ips)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetVpcIpsFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ipv6(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "ipv6")

    @_builtins.property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[_builtins.int]:
        """
        The unique globally general API entity identifier for the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @_builtins.property
    @pulumi.getter(name="vpcIps")
    def vpc_ips(self) -> Optional[Sequence['outputs.GetVpcIpsVpcIpResult']]:
        return pulumi.get(self, "vpc_ips")


class AwaitableGetVpcIpsResult(GetVpcIpsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpcIpsResult(
            filters=self.filters,
            id=self.id,
            ipv6=self.ipv6,
            vpc_id=self.vpc_id,
            vpc_ips=self.vpc_ips)


def get_vpc_ips(filters: Optional[Sequence[Union['GetVpcIpsFilterArgs', 'GetVpcIpsFilterArgsDict']]] = None,
                ipv6: Optional[_builtins.bool] = None,
                vpc_id: Optional[_builtins.int] = None,
                vpc_ips: Optional[Sequence[Union['GetVpcIpsVpcIpArgs', 'GetVpcIpsVpcIpArgsDict']]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpcIpsResult:
    """
    Provides information about a list of Linode VPC IPs that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-vpcs-ips).

    ## Example Usage

    The following example shows how one might use this data source to list VPC IPs.

    ```python
    import pulumi
    import pulumi_linode as linode

    filtered_ips = linode.get_vpc_ips(filters=[{
        "name": "address",
        "values": ["10.0.0.0"],
    }])
    pulumi.export("vpcIps", filtered_ips.vpc_ips)
    ```

    One might also use this data source to list all VPC IPs in a specific VPC. The following example shows how to do this.

    ```python
    import pulumi
    import pulumi_linode as linode

    specific_vpc_ips = linode.get_vpc_ips(vpc_id=123)
    pulumi.export("vpcIps", specific_vpc_ips.vpc_ips)
    ```

    By default, this data source retrieves only IPv4 addresses. To instead retrieve IPv6 addresses, the `ipv6` field should be set to true:

    ```python
    import pulumi
    import pulumi_linode as linode

    all_vpc_ipv6 = linode.get_vpc_ips(ipv6=True)
    ```

    ## Filterable Fields

    * `active`

    * `config_id`

    * `linode_id`

    * `region`

    * `vpc_id`


    :param _builtins.int vpc_id: The id of the parent VPC for the list of VPC IPs.
           
           * `filter` - (Optional) A set of filters used to select Linode VPC IPs that meet certain requirements.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['ipv6'] = ipv6
    __args__['vpcId'] = vpc_id
    __args__['vpcIps'] = vpc_ips
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getVpcIps:getVpcIps', __args__, opts=opts, typ=GetVpcIpsResult).value

    return AwaitableGetVpcIpsResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        ipv6=pulumi.get(__ret__, 'ipv6'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        vpc_ips=pulumi.get(__ret__, 'vpc_ips'))
def get_vpc_ips_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetVpcIpsFilterArgs', 'GetVpcIpsFilterArgsDict']]]]] = None,
                       ipv6: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                       vpc_id: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                       vpc_ips: Optional[pulumi.Input[Optional[Sequence[Union['GetVpcIpsVpcIpArgs', 'GetVpcIpsVpcIpArgsDict']]]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVpcIpsResult]:
    """
    Provides information about a list of Linode VPC IPs that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-vpcs-ips).

    ## Example Usage

    The following example shows how one might use this data source to list VPC IPs.

    ```python
    import pulumi
    import pulumi_linode as linode

    filtered_ips = linode.get_vpc_ips(filters=[{
        "name": "address",
        "values": ["10.0.0.0"],
    }])
    pulumi.export("vpcIps", filtered_ips.vpc_ips)
    ```

    One might also use this data source to list all VPC IPs in a specific VPC. The following example shows how to do this.

    ```python
    import pulumi
    import pulumi_linode as linode

    specific_vpc_ips = linode.get_vpc_ips(vpc_id=123)
    pulumi.export("vpcIps", specific_vpc_ips.vpc_ips)
    ```

    By default, this data source retrieves only IPv4 addresses. To instead retrieve IPv6 addresses, the `ipv6` field should be set to true:

    ```python
    import pulumi
    import pulumi_linode as linode

    all_vpc_ipv6 = linode.get_vpc_ips(ipv6=True)
    ```

    ## Filterable Fields

    * `active`

    * `config_id`

    * `linode_id`

    * `region`

    * `vpc_id`


    :param _builtins.int vpc_id: The id of the parent VPC for the list of VPC IPs.
           
           * `filter` - (Optional) A set of filters used to select Linode VPC IPs that meet certain requirements.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['ipv6'] = ipv6
    __args__['vpcId'] = vpc_id
    __args__['vpcIps'] = vpc_ips
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getVpcIps:getVpcIps', __args__, opts=opts, typ=GetVpcIpsResult)
    return __ret__.apply(lambda __response__: GetVpcIpsResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        ipv6=pulumi.get(__response__, 'ipv6'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        vpc_ips=pulumi.get(__response__, 'vpc_ips')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetImageResult',
    'AwaitableGetImageResult',
    'get_image',
    'get_image_output',
]

@pulumi.output_type
class GetImageResult:
    """
    A collection of values returned by getImage.
    """
    def __init__(__self__, capabilities=None, created=None, created_by=None, deprecated=None, description=None, expiry=None, id=None, is_public=None, label=None, replications=None, size=None, status=None, tags=None, total_size=None, type=None, vendor=None):
        if capabilities and not isinstance(capabilities, list):
            raise TypeError("Expected argument 'capabilities' to be a list")
        pulumi.set(__self__, "capabilities", capabilities)
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if deprecated and not isinstance(deprecated, bool):
            raise TypeError("Expected argument 'deprecated' to be a bool")
        pulumi.set(__self__, "deprecated", deprecated)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if expiry and not isinstance(expiry, str):
            raise TypeError("Expected argument 'expiry' to be a str")
        pulumi.set(__self__, "expiry", expiry)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_public and not isinstance(is_public, bool):
            raise TypeError("Expected argument 'is_public' to be a bool")
        pulumi.set(__self__, "is_public", is_public)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if replications and not isinstance(replications, list):
            raise TypeError("Expected argument 'replications' to be a list")
        pulumi.set(__self__, "replications", replications)
        if size and not isinstance(size, int):
            raise TypeError("Expected argument 'size' to be a int")
        pulumi.set(__self__, "size", size)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if total_size and not isinstance(total_size, int):
            raise TypeError("Expected argument 'total_size' to be a int")
        pulumi.set(__self__, "total_size", total_size)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if vendor and not isinstance(vendor, str):
            raise TypeError("Expected argument 'vendor' to be a str")
        pulumi.set(__self__, "vendor", vendor)

    @_builtins.property
    @pulumi.getter
    def capabilities(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "capabilities")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        When this Image was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        """
        The name of the User who created this Image, or "linode" for official Images.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def deprecated(self) -> _builtins.bool:
        """
        Whether or not this Image is deprecated. Will only be true for deprecated public Images.
        """
        return pulumi.get(self, "deprecated")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        A detailed description of this Image.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def expiry(self) -> _builtins.str:
        return pulumi.get(self, "expiry")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> _builtins.bool:
        """
        True if the Image is public.
        """
        return pulumi.get(self, "is_public")

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        A short description of the Image.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def replications(self) -> Optional[Sequence['outputs.GetImageReplicationResult']]:
        """
        A list of image replication regions and corresponding status.
        """
        return pulumi.get(self, "replications")

    @_builtins.property
    @pulumi.getter
    def size(self) -> _builtins.int:
        """
        The minimum size this Image needs to deploy. Size is in MB. example: 2500
        """
        return pulumi.get(self, "size")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of an image replica.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        A list of customized tags.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="totalSize")
    def total_size(self) -> _builtins.int:
        """
        The total size of the image in all available regions.
        """
        return pulumi.get(self, "total_size")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        How the Image was created. Manual Images can be created at any time. "Automatic" Images are created automatically from a deleted Linode. (`manual`, `automatic`)
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def vendor(self) -> _builtins.str:
        """
        The upstream distribution vendor. `None` for private Images.
        """
        return pulumi.get(self, "vendor")


class AwaitableGetImageResult(GetImageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetImageResult(
            capabilities=self.capabilities,
            created=self.created,
            created_by=self.created_by,
            deprecated=self.deprecated,
            description=self.description,
            expiry=self.expiry,
            id=self.id,
            is_public=self.is_public,
            label=self.label,
            replications=self.replications,
            size=self.size,
            status=self.status,
            tags=self.tags,
            total_size=self.total_size,
            type=self.type,
            vendor=self.vendor)


def get_image(id: Optional[_builtins.str] = None,
              replications: Optional[Sequence[Union['GetImageReplicationArgs', 'GetImageReplicationArgsDict']]] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetImageResult:
    """
    Provides information about a Linode image
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-image).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode image.

    ```python
    import pulumi
    import pulumi_linode as linode

    k8_master = linode.get_image(id="linode/debian12")
    ```


    :param _builtins.str id: The unique ID of this Image.  The ID of private images begin with `private/` followed by the numeric identifier of the private image, for example `private/12345`.
    :param Sequence[Union['GetImageReplicationArgs', 'GetImageReplicationArgsDict']] replications: A list of image replication regions and corresponding status.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['replications'] = replications
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getImage:getImage', __args__, opts=opts, typ=GetImageResult).value

    return AwaitableGetImageResult(
        capabilities=pulumi.get(__ret__, 'capabilities'),
        created=pulumi.get(__ret__, 'created'),
        created_by=pulumi.get(__ret__, 'created_by'),
        deprecated=pulumi.get(__ret__, 'deprecated'),
        description=pulumi.get(__ret__, 'description'),
        expiry=pulumi.get(__ret__, 'expiry'),
        id=pulumi.get(__ret__, 'id'),
        is_public=pulumi.get(__ret__, 'is_public'),
        label=pulumi.get(__ret__, 'label'),
        replications=pulumi.get(__ret__, 'replications'),
        size=pulumi.get(__ret__, 'size'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        total_size=pulumi.get(__ret__, 'total_size'),
        type=pulumi.get(__ret__, 'type'),
        vendor=pulumi.get(__ret__, 'vendor'))
def get_image_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                     replications: Optional[pulumi.Input[Optional[Sequence[Union['GetImageReplicationArgs', 'GetImageReplicationArgsDict']]]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetImageResult]:
    """
    Provides information about a Linode image
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-image).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode image.

    ```python
    import pulumi
    import pulumi_linode as linode

    k8_master = linode.get_image(id="linode/debian12")
    ```


    :param _builtins.str id: The unique ID of this Image.  The ID of private images begin with `private/` followed by the numeric identifier of the private image, for example `private/12345`.
    :param Sequence[Union['GetImageReplicationArgs', 'GetImageReplicationArgsDict']] replications: A list of image replication regions and corresponding status.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['replications'] = replications
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getImage:getImage', __args__, opts=opts, typ=GetImageResult)
    return __ret__.apply(lambda __response__: GetImageResult(
        capabilities=pulumi.get(__response__, 'capabilities'),
        created=pulumi.get(__response__, 'created'),
        created_by=pulumi.get(__response__, 'created_by'),
        deprecated=pulumi.get(__response__, 'deprecated'),
        description=pulumi.get(__response__, 'description'),
        expiry=pulumi.get(__response__, 'expiry'),
        id=pulumi.get(__response__, 'id'),
        is_public=pulumi.get(__response__, 'is_public'),
        label=pulumi.get(__response__, 'label'),
        replications=pulumi.get(__response__, 'replications'),
        size=pulumi.get(__response__, 'size'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        total_size=pulumi.get(__response__, 'total_size'),
        type=pulumi.get(__response__, 'type'),
        vendor=pulumi.get(__response__, 'vendor')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetVolumeResult',
    'AwaitableGetVolumeResult',
    'get_volume',
    'get_volume_output',
]

@pulumi.output_type
class GetVolumeResult:
    """
    A collection of values returned by getVolume.
    """
    def __init__(__self__, created=None, encryption=None, filesystem_path=None, id=None, label=None, linode_id=None, region=None, size=None, status=None, tags=None, updated=None):
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if encryption and not isinstance(encryption, str):
            raise TypeError("Expected argument 'encryption' to be a str")
        pulumi.set(__self__, "encryption", encryption)
        if filesystem_path and not isinstance(filesystem_path, str):
            raise TypeError("Expected argument 'filesystem_path' to be a str")
        pulumi.set(__self__, "filesystem_path", filesystem_path)
        if id and not isinstance(id, int):
            raise TypeError("Expected argument 'id' to be a int")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if linode_id and not isinstance(linode_id, int):
            raise TypeError("Expected argument 'linode_id' to be a int")
        pulumi.set(__self__, "linode_id", linode_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if size and not isinstance(size, int):
            raise TypeError("Expected argument 'size' to be a int")
        pulumi.set(__self__, "size", size)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated and not isinstance(updated, str):
            raise TypeError("Expected argument 'updated' to be a str")
        pulumi.set(__self__, "updated", updated)

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        When this Volume was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> _builtins.str:
        """
        Whether Block Storage Disk Encryption is enabled or disabled on this Volume.
        """
        return pulumi.get(self, "encryption")

    @_builtins.property
    @pulumi.getter(name="filesystemPath")
    def filesystem_path(self) -> _builtins.str:
        """
        The full filesystem path for the Volume based on the Volume's label. Path is /dev/disk/by-id/scsi-0LinodeVolume + Volume label.
        """
        return pulumi.get(self, "filesystem_path")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.int:
        """
        The unique ID of this Volume.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        This Volume's label is for display purposes only.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> _builtins.int:
        """
        If a Volume is attached to a specific Linode, the ID of that Linode will be displayed here. If the Volume is unattached, this value will be null.
        """
        return pulumi.get(self, "linode_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The datacenter in which this Volume is located. See all regions [here](https://api.linode.com/v4/regions).
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def size(self) -> _builtins.int:
        """
        The Volume's size, in GiB.
        """
        return pulumi.get(self, "size")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The current status of the Volume. (`creating`, `active`, `resizing`, `contact_support`)
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        An array of tags applied to this object. Tags are case-insensitive and are for organizational purposes only.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def updated(self) -> _builtins.str:
        """
        When this Volume was last updated.
        """
        return pulumi.get(self, "updated")


class AwaitableGetVolumeResult(GetVolumeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVolumeResult(
            created=self.created,
            encryption=self.encryption,
            filesystem_path=self.filesystem_path,
            id=self.id,
            label=self.label,
            linode_id=self.linode_id,
            region=self.region,
            size=self.size,
            status=self.status,
            tags=self.tags,
            updated=self.updated)


def get_volume(id: Optional[_builtins.int] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVolumeResult:
    """
    Provides information about a Linode Volume.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-volume).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode Volume.

    ```python
    import pulumi
    import pulumi_linode as linode

    foo = linode.get_volume(id=1234567)
    ```


    :param _builtins.int id: The unique numeric ID of the Volume record to query.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getVolume:getVolume', __args__, opts=opts, typ=GetVolumeResult).value

    return AwaitableGetVolumeResult(
        created=pulumi.get(__ret__, 'created'),
        encryption=pulumi.get(__ret__, 'encryption'),
        filesystem_path=pulumi.get(__ret__, 'filesystem_path'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        linode_id=pulumi.get(__ret__, 'linode_id'),
        region=pulumi.get(__ret__, 'region'),
        size=pulumi.get(__ret__, 'size'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated=pulumi.get(__ret__, 'updated'))
def get_volume_output(id: Optional[pulumi.Input[_builtins.int]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVolumeResult]:
    """
    Provides information about a Linode Volume.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-volume).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode Volume.

    ```python
    import pulumi
    import pulumi_linode as linode

    foo = linode.get_volume(id=1234567)
    ```


    :param _builtins.int id: The unique numeric ID of the Volume record to query.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getVolume:getVolume', __args__, opts=opts, typ=GetVolumeResult)
    return __ret__.apply(lambda __response__: GetVolumeResult(
        created=pulumi.get(__response__, 'created'),
        encryption=pulumi.get(__response__, 'encryption'),
        filesystem_path=pulumi.get(__response__, 'filesystem_path'),
        id=pulumi.get(__response__, 'id'),
        label=pulumi.get(__response__, 'label'),
        linode_id=pulumi.get(__response__, 'linode_id'),
        region=pulumi.get(__response__, 'region'),
        size=pulumi.get(__response__, 'size'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated=pulumi.get(__response__, 'updated')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ObjectStorageBucketArgs', 'ObjectStorageBucket']

@pulumi.input_type
class ObjectStorageBucketArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[_builtins.str],
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 acl: Optional[pulumi.Input[_builtins.str]] = None,
                 cert: Optional[pulumi.Input['ObjectStorageBucketCertArgs']] = None,
                 cluster: Optional[pulumi.Input[_builtins.str]] = None,
                 cors_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 endpoint_type: Optional[pulumi.Input[_builtins.str]] = None,
                 lifecycle_rules: Optional[pulumi.Input[Sequence[pulumi.Input['ObjectStorageBucketLifecycleRuleArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 s3_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 versioning: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ObjectStorageBucket resource.
        :param pulumi.Input[_builtins.str] label: The label of the Linode Object Storage Bucket.
        :param pulumi.Input[_builtins.str] access_key: The access key to authenticate with. If not specified with the resource, its value can be
               * configured by `obj_access_key` in the provider configuration;
               * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        :param pulumi.Input[_builtins.str] acl: The Access Control Level of the bucket using a canned ACL string. See all ACL strings [in the Linode API v4 documentation](https://techdocs.akamai.com/linode-api/reference/post-object-storage-bucket).
        :param pulumi.Input['ObjectStorageBucketCertArgs'] cert: The cert used by this Object Storage Bucket.
        :param pulumi.Input[_builtins.str] cluster: The cluster of the Linode Object Storage Bucket. This is deprecated in favor of `region` attribute.
               For example, `us-mia-1` cluster can be translated into `us-mia` region. Exactly one of `region` and `cluster` is required for creating a bucket.
        :param pulumi.Input[_builtins.bool] cors_enabled: If true, the bucket will have CORS enabled for all origins. Not supported by E2/E3 endpoints.
        :param pulumi.Input[_builtins.str] endpoint_type: The type of `s3_endpoint` available to the user in this region. See [Endpoint types](https://techdocs.akamai.com/cloud-computing/docs/object-storage#endpoint-type) for more information.
        :param pulumi.Input[Sequence[pulumi.Input['ObjectStorageBucketLifecycleRuleArgs']]] lifecycle_rules: Lifecycle rules to be applied to the bucket.
        :param pulumi.Input[_builtins.str] region: The region of the Linode Object Storage Bucket. Exactly one of `region` and `cluster` is required for creating a bucket.
        :param pulumi.Input[_builtins.str] s3_endpoint: The user's s3 endpoint URL, based on the `endpoint_type` and `region`.
        :param pulumi.Input[_builtins.str] secret_key: The secret key to authenticate with. If not specified with the resource, its value can be
               * configured by `obj_secret_key` in the provider configuration;
               * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        :param pulumi.Input[_builtins.bool] versioning: Whether to enable versioning. Once you version-enable a bucket, it can never return to an unversioned state. You can, however, suspend versioning on that bucket. (Requires `access_key` and `secret_key`)
               
               * `lifecycle_rule` - (Optional) Lifecycle rules to be applied to the bucket. (Requires `access_key` and `secret_key`)
               
               * `cert` - (Optional) The bucket's TLS/SSL certificate.
        """
        pulumi.set(__self__, "label", label)
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if acl is not None:
            pulumi.set(__self__, "acl", acl)
        if cert is not None:
            pulumi.set(__self__, "cert", cert)
        if cluster is not None:
            warnings.warn("""The cluster attribute has been deprecated, please consider switching to the region attribute. For example, a cluster value of `us-mia-1` can be translated to a region value of `us-mia`.""", DeprecationWarning)
            pulumi.log.warn("""cluster is deprecated: The cluster attribute has been deprecated, please consider switching to the region attribute. For example, a cluster value of `us-mia-1` can be translated to a region value of `us-mia`.""")
        if cluster is not None:
            pulumi.set(__self__, "cluster", cluster)
        if cors_enabled is not None:
            pulumi.set(__self__, "cors_enabled", cors_enabled)
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if lifecycle_rules is not None:
            pulumi.set(__self__, "lifecycle_rules", lifecycle_rules)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if s3_endpoint is not None:
            pulumi.set(__self__, "s3_endpoint", s3_endpoint)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if versioning is not None:
            pulumi.set(__self__, "versioning", versioning)

    @_builtins.property
    @pulumi.getter
    def label(self) -> pulumi.Input[_builtins.str]:
        """
        The label of the Linode Object Storage Bucket.
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access key to authenticate with. If not specified with the resource, its value can be
        * configured by `obj_access_key` in the provider configuration;
        * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key", value)

    @_builtins.property
    @pulumi.getter
    def acl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Access Control Level of the bucket using a canned ACL string. See all ACL strings [in the Linode API v4 documentation](https://techdocs.akamai.com/linode-api/reference/post-object-storage-bucket).
        """
        return pulumi.get(self, "acl")

    @acl.setter
    def acl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "acl", value)

    @_builtins.property
    @pulumi.getter
    def cert(self) -> Optional[pulumi.Input['ObjectStorageBucketCertArgs']]:
        """
        The cert used by this Object Storage Bucket.
        """
        return pulumi.get(self, "cert")

    @cert.setter
    def cert(self, value: Optional[pulumi.Input['ObjectStorageBucketCertArgs']]):
        pulumi.set(self, "cert", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""The cluster attribute has been deprecated, please consider switching to the region attribute. For example, a cluster value of `us-mia-1` can be translated to a region value of `us-mia`.""")
    def cluster(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cluster of the Linode Object Storage Bucket. This is deprecated in favor of `region` attribute.
        For example, `us-mia-1` cluster can be translated into `us-mia` region. Exactly one of `region` and `cluster` is required for creating a bucket.
        """
        return pulumi.get(self, "cluster")

    @cluster.setter
    def cluster(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster", value)

    @_builtins.property
    @pulumi.getter(name="corsEnabled")
    def cors_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, the bucket will have CORS enabled for all origins. Not supported by E2/E3 endpoints.
        """
        return pulumi.get(self, "cors_enabled")

    @cors_enabled.setter
    def cors_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "cors_enabled", value)

    @_builtins.property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of `s3_endpoint` available to the user in this region. See [Endpoint types](https://techdocs.akamai.com/cloud-computing/docs/object-storage#endpoint-type) for more information.
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_type", value)

    @_builtins.property
    @pulumi.getter(name="lifecycleRules")
    def lifecycle_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ObjectStorageBucketLifecycleRuleArgs']]]]:
        """
        Lifecycle rules to be applied to the bucket.
        """
        return pulumi.get(self, "lifecycle_rules")

    @lifecycle_rules.setter
    def lifecycle_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ObjectStorageBucketLifecycleRuleArgs']]]]):
        pulumi.set(self, "lifecycle_rules", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region of the Linode Object Storage Bucket. Exactly one of `region` and `cluster` is required for creating a bucket.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="s3Endpoint")
    def s3_endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The user's s3 endpoint URL, based on the `endpoint_type` and `region`.
        """
        return pulumi.get(self, "s3_endpoint")

    @s3_endpoint.setter
    def s3_endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "s3_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secret key to authenticate with. If not specified with the resource, its value can be
        * configured by `obj_secret_key` in the provider configuration;
        * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_key", value)

    @_builtins.property
    @pulumi.getter
    def versioning(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable versioning. Once you version-enable a bucket, it can never return to an unversioned state. You can, however, suspend versioning on that bucket. (Requires `access_key` and `secret_key`)

        * `lifecycle_rule` - (Optional) Lifecycle rules to be applied to the bucket. (Requires `access_key` and `secret_key`)

        * `cert` - (Optional) The bucket's TLS/SSL certificate.
        """
        return pulumi.get(self, "versioning")

    @versioning.setter
    def versioning(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "versioning", value)


@pulumi.input_type
class _ObjectStorageBucketState:
    def __init__(__self__, *,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 acl: Optional[pulumi.Input[_builtins.str]] = None,
                 cert: Optional[pulumi.Input['ObjectStorageBucketCertArgs']] = None,
                 cluster: Optional[pulumi.Input[_builtins.str]] = None,
                 cors_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[_builtins.str]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 lifecycle_rules: Optional[pulumi.Input[Sequence[pulumi.Input['ObjectStorageBucketLifecycleRuleArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 s3_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 versioning: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering ObjectStorageBucket resources.
        :param pulumi.Input[_builtins.str] access_key: The access key to authenticate with. If not specified with the resource, its value can be
               * configured by `obj_access_key` in the provider configuration;
               * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        :param pulumi.Input[_builtins.str] acl: The Access Control Level of the bucket using a canned ACL string. See all ACL strings [in the Linode API v4 documentation](https://techdocs.akamai.com/linode-api/reference/post-object-storage-bucket).
        :param pulumi.Input['ObjectStorageBucketCertArgs'] cert: The cert used by this Object Storage Bucket.
        :param pulumi.Input[_builtins.str] cluster: The cluster of the Linode Object Storage Bucket. This is deprecated in favor of `region` attribute.
               For example, `us-mia-1` cluster can be translated into `us-mia` region. Exactly one of `region` and `cluster` is required for creating a bucket.
        :param pulumi.Input[_builtins.bool] cors_enabled: If true, the bucket will have CORS enabled for all origins. Not supported by E2/E3 endpoints.
        :param pulumi.Input[_builtins.str] endpoint: The endpoint for the bucket used for s3 connections.
        :param pulumi.Input[_builtins.str] endpoint_type: The type of `s3_endpoint` available to the user in this region. See [Endpoint types](https://techdocs.akamai.com/cloud-computing/docs/object-storage#endpoint-type) for more information.
        :param pulumi.Input[_builtins.str] hostname: The hostname where this bucket can be accessed. This hostname can be accessed through a browser if the bucket is made public.
        :param pulumi.Input[_builtins.str] label: The label of the Linode Object Storage Bucket.
        :param pulumi.Input[Sequence[pulumi.Input['ObjectStorageBucketLifecycleRuleArgs']]] lifecycle_rules: Lifecycle rules to be applied to the bucket.
        :param pulumi.Input[_builtins.str] region: The region of the Linode Object Storage Bucket. Exactly one of `region` and `cluster` is required for creating a bucket.
        :param pulumi.Input[_builtins.str] s3_endpoint: The user's s3 endpoint URL, based on the `endpoint_type` and `region`.
        :param pulumi.Input[_builtins.str] secret_key: The secret key to authenticate with. If not specified with the resource, its value can be
               * configured by `obj_secret_key` in the provider configuration;
               * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        :param pulumi.Input[_builtins.bool] versioning: Whether to enable versioning. Once you version-enable a bucket, it can never return to an unversioned state. You can, however, suspend versioning on that bucket. (Requires `access_key` and `secret_key`)
               
               * `lifecycle_rule` - (Optional) Lifecycle rules to be applied to the bucket. (Requires `access_key` and `secret_key`)
               
               * `cert` - (Optional) The bucket's TLS/SSL certificate.
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if acl is not None:
            pulumi.set(__self__, "acl", acl)
        if cert is not None:
            pulumi.set(__self__, "cert", cert)
        if cluster is not None:
            warnings.warn("""The cluster attribute has been deprecated, please consider switching to the region attribute. For example, a cluster value of `us-mia-1` can be translated to a region value of `us-mia`.""", DeprecationWarning)
            pulumi.log.warn("""cluster is deprecated: The cluster attribute has been deprecated, please consider switching to the region attribute. For example, a cluster value of `us-mia-1` can be translated to a region value of `us-mia`.""")
        if cluster is not None:
            pulumi.set(__self__, "cluster", cluster)
        if cors_enabled is not None:
            pulumi.set(__self__, "cors_enabled", cors_enabled)
        if endpoint is not None:
            warnings.warn("""Use `s3_endpoint` instead""", DeprecationWarning)
            pulumi.log.warn("""endpoint is deprecated: Use `s3_endpoint` instead""")
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if label is not None:
            pulumi.set(__self__, "label", label)
        if lifecycle_rules is not None:
            pulumi.set(__self__, "lifecycle_rules", lifecycle_rules)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if s3_endpoint is not None:
            pulumi.set(__self__, "s3_endpoint", s3_endpoint)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if versioning is not None:
            pulumi.set(__self__, "versioning", versioning)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access key to authenticate with. If not specified with the resource, its value can be
        * configured by `obj_access_key` in the provider configuration;
        * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key", value)

    @_builtins.property
    @pulumi.getter
    def acl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Access Control Level of the bucket using a canned ACL string. See all ACL strings [in the Linode API v4 documentation](https://techdocs.akamai.com/linode-api/reference/post-object-storage-bucket).
        """
        return pulumi.get(self, "acl")

    @acl.setter
    def acl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "acl", value)

    @_builtins.property
    @pulumi.getter
    def cert(self) -> Optional[pulumi.Input['ObjectStorageBucketCertArgs']]:
        """
        The cert used by this Object Storage Bucket.
        """
        return pulumi.get(self, "cert")

    @cert.setter
    def cert(self, value: Optional[pulumi.Input['ObjectStorageBucketCertArgs']]):
        pulumi.set(self, "cert", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""The cluster attribute has been deprecated, please consider switching to the region attribute. For example, a cluster value of `us-mia-1` can be translated to a region value of `us-mia`.""")
    def cluster(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cluster of the Linode Object Storage Bucket. This is deprecated in favor of `region` attribute.
        For example, `us-mia-1` cluster can be translated into `us-mia` region. Exactly one of `region` and `cluster` is required for creating a bucket.
        """
        return pulumi.get(self, "cluster")

    @cluster.setter
    def cluster(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster", value)

    @_builtins.property
    @pulumi.getter(name="corsEnabled")
    def cors_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, the bucket will have CORS enabled for all origins. Not supported by E2/E3 endpoints.
        """
        return pulumi.get(self, "cors_enabled")

    @cors_enabled.setter
    def cors_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "cors_enabled", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Use `s3_endpoint` instead""")
    def endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The endpoint for the bucket used for s3 connections.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of `s3_endpoint` available to the user in this region. See [Endpoint types](https://techdocs.akamai.com/cloud-computing/docs/object-storage#endpoint-type) for more information.
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_type", value)

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hostname where this bucket can be accessed. This hostname can be accessed through a browser if the bucket is made public.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hostname", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The label of the Linode Object Storage Bucket.
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter(name="lifecycleRules")
    def lifecycle_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ObjectStorageBucketLifecycleRuleArgs']]]]:
        """
        Lifecycle rules to be applied to the bucket.
        """
        return pulumi.get(self, "lifecycle_rules")

    @lifecycle_rules.setter
    def lifecycle_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ObjectStorageBucketLifecycleRuleArgs']]]]):
        pulumi.set(self, "lifecycle_rules", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region of the Linode Object Storage Bucket. Exactly one of `region` and `cluster` is required for creating a bucket.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="s3Endpoint")
    def s3_endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The user's s3 endpoint URL, based on the `endpoint_type` and `region`.
        """
        return pulumi.get(self, "s3_endpoint")

    @s3_endpoint.setter
    def s3_endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "s3_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secret key to authenticate with. If not specified with the resource, its value can be
        * configured by `obj_secret_key` in the provider configuration;
        * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_key", value)

    @_builtins.property
    @pulumi.getter
    def versioning(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable versioning. Once you version-enable a bucket, it can never return to an unversioned state. You can, however, suspend versioning on that bucket. (Requires `access_key` and `secret_key`)

        * `lifecycle_rule` - (Optional) Lifecycle rules to be applied to the bucket. (Requires `access_key` and `secret_key`)

        * `cert` - (Optional) The bucket's TLS/SSL certificate.
        """
        return pulumi.get(self, "versioning")

    @versioning.setter
    def versioning(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "versioning", value)


@pulumi.type_token("linode:index/objectStorageBucket:ObjectStorageBucket")
class ObjectStorageBucket(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 acl: Optional[pulumi.Input[_builtins.str]] = None,
                 cert: Optional[pulumi.Input[Union['ObjectStorageBucketCertArgs', 'ObjectStorageBucketCertArgsDict']]] = None,
                 cluster: Optional[pulumi.Input[_builtins.str]] = None,
                 cors_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 endpoint_type: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 lifecycle_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ObjectStorageBucketLifecycleRuleArgs', 'ObjectStorageBucketLifecycleRuleArgsDict']]]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 s3_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 versioning: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Provides a Linode Object Storage Bucket resource. This can be used to create, modify, and delete Linodes Object Storage Buckets.
        For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/post-object-storage-bucket).

        ## Example Usage

        The following example shows how one might use this resource to create an Object Storage Bucket:

        ```python
        import pulumi
        import pulumi_linode as linode

        foobar = linode.ObjectStorageBucket("foobar",
            region="us-mia",
            label="mybucket")
        ```

        Creating an Object Storage Bucket with Lifecycle rules:

        ```python
        import pulumi
        import pulumi_linode as linode

        mykey = linode.ObjectStorageKey("mykey", label="image-access")
        mybucket = linode.ObjectStorageBucket("mybucket",
            access_key=mykey.access_key,
            secret_key=mykey.secret_key,
            region="us-mia",
            label="mybucket",
            lifecycle_rules=[{
                "id": "my-rule",
                "enabled": True,
                "abort_incomplete_multipart_upload_days": 5,
                "expiration": {
                    "date": "2021-06-21",
                },
            }])
        ```

        Creating an Object Storage Bucket with Lifecycle rules using provider-level object credentials

        ## Import

        Linodes Object Storage Buckets can be imported using the resource `id` which is made of `cluster:label`, e.g.

        ```sh
        $ pulumi import linode:index/objectStorageBucket:ObjectStorageBucket mybucket us-east-1:foobar
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_key: The access key to authenticate with. If not specified with the resource, its value can be
               * configured by `obj_access_key` in the provider configuration;
               * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        :param pulumi.Input[_builtins.str] acl: The Access Control Level of the bucket using a canned ACL string. See all ACL strings [in the Linode API v4 documentation](https://techdocs.akamai.com/linode-api/reference/post-object-storage-bucket).
        :param pulumi.Input[Union['ObjectStorageBucketCertArgs', 'ObjectStorageBucketCertArgsDict']] cert: The cert used by this Object Storage Bucket.
        :param pulumi.Input[_builtins.str] cluster: The cluster of the Linode Object Storage Bucket. This is deprecated in favor of `region` attribute.
               For example, `us-mia-1` cluster can be translated into `us-mia` region. Exactly one of `region` and `cluster` is required for creating a bucket.
        :param pulumi.Input[_builtins.bool] cors_enabled: If true, the bucket will have CORS enabled for all origins. Not supported by E2/E3 endpoints.
        :param pulumi.Input[_builtins.str] endpoint_type: The type of `s3_endpoint` available to the user in this region. See [Endpoint types](https://techdocs.akamai.com/cloud-computing/docs/object-storage#endpoint-type) for more information.
        :param pulumi.Input[_builtins.str] label: The label of the Linode Object Storage Bucket.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ObjectStorageBucketLifecycleRuleArgs', 'ObjectStorageBucketLifecycleRuleArgsDict']]]] lifecycle_rules: Lifecycle rules to be applied to the bucket.
        :param pulumi.Input[_builtins.str] region: The region of the Linode Object Storage Bucket. Exactly one of `region` and `cluster` is required for creating a bucket.
        :param pulumi.Input[_builtins.str] s3_endpoint: The user's s3 endpoint URL, based on the `endpoint_type` and `region`.
        :param pulumi.Input[_builtins.str] secret_key: The secret key to authenticate with. If not specified with the resource, its value can be
               * configured by `obj_secret_key` in the provider configuration;
               * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        :param pulumi.Input[_builtins.bool] versioning: Whether to enable versioning. Once you version-enable a bucket, it can never return to an unversioned state. You can, however, suspend versioning on that bucket. (Requires `access_key` and `secret_key`)
               
               * `lifecycle_rule` - (Optional) Lifecycle rules to be applied to the bucket. (Requires `access_key` and `secret_key`)
               
               * `cert` - (Optional) The bucket's TLS/SSL certificate.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ObjectStorageBucketArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Linode Object Storage Bucket resource. This can be used to create, modify, and delete Linodes Object Storage Buckets.
        For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/post-object-storage-bucket).

        ## Example Usage

        The following example shows how one might use this resource to create an Object Storage Bucket:

        ```python
        import pulumi
        import pulumi_linode as linode

        foobar = linode.ObjectStorageBucket("foobar",
            region="us-mia",
            label="mybucket")
        ```

        Creating an Object Storage Bucket with Lifecycle rules:

        ```python
        import pulumi
        import pulumi_linode as linode

        mykey = linode.ObjectStorageKey("mykey", label="image-access")
        mybucket = linode.ObjectStorageBucket("mybucket",
            access_key=mykey.access_key,
            secret_key=mykey.secret_key,
            region="us-mia",
            label="mybucket",
            lifecycle_rules=[{
                "id": "my-rule",
                "enabled": True,
                "abort_incomplete_multipart_upload_days": 5,
                "expiration": {
                    "date": "2021-06-21",
                },
            }])
        ```

        Creating an Object Storage Bucket with Lifecycle rules using provider-level object credentials

        ## Import

        Linodes Object Storage Buckets can be imported using the resource `id` which is made of `cluster:label`, e.g.

        ```sh
        $ pulumi import linode:index/objectStorageBucket:ObjectStorageBucket mybucket us-east-1:foobar
        ```

        :param str resource_name: The name of the resource.
        :param ObjectStorageBucketArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ObjectStorageBucketArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 acl: Optional[pulumi.Input[_builtins.str]] = None,
                 cert: Optional[pulumi.Input[Union['ObjectStorageBucketCertArgs', 'ObjectStorageBucketCertArgsDict']]] = None,
                 cluster: Optional[pulumi.Input[_builtins.str]] = None,
                 cors_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 endpoint_type: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 lifecycle_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ObjectStorageBucketLifecycleRuleArgs', 'ObjectStorageBucketLifecycleRuleArgsDict']]]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 s3_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 versioning: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ObjectStorageBucketArgs.__new__(ObjectStorageBucketArgs)

            __props__.__dict__["access_key"] = access_key
            __props__.__dict__["acl"] = acl
            __props__.__dict__["cert"] = cert
            __props__.__dict__["cluster"] = cluster
            __props__.__dict__["cors_enabled"] = cors_enabled
            __props__.__dict__["endpoint_type"] = endpoint_type
            if label is None and not opts.urn:
                raise TypeError("Missing required property 'label'")
            __props__.__dict__["label"] = label
            __props__.__dict__["lifecycle_rules"] = lifecycle_rules
            __props__.__dict__["region"] = region
            __props__.__dict__["s3_endpoint"] = s3_endpoint
            __props__.__dict__["secret_key"] = None if secret_key is None else pulumi.Output.secret(secret_key)
            __props__.__dict__["versioning"] = versioning
            __props__.__dict__["endpoint"] = None
            __props__.__dict__["hostname"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secretKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ObjectStorageBucket, __self__).__init__(
            'linode:index/objectStorageBucket:ObjectStorageBucket',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key: Optional[pulumi.Input[_builtins.str]] = None,
            acl: Optional[pulumi.Input[_builtins.str]] = None,
            cert: Optional[pulumi.Input[Union['ObjectStorageBucketCertArgs', 'ObjectStorageBucketCertArgsDict']]] = None,
            cluster: Optional[pulumi.Input[_builtins.str]] = None,
            cors_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            endpoint_type: Optional[pulumi.Input[_builtins.str]] = None,
            hostname: Optional[pulumi.Input[_builtins.str]] = None,
            label: Optional[pulumi.Input[_builtins.str]] = None,
            lifecycle_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ObjectStorageBucketLifecycleRuleArgs', 'ObjectStorageBucketLifecycleRuleArgsDict']]]]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            s3_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            secret_key: Optional[pulumi.Input[_builtins.str]] = None,
            versioning: Optional[pulumi.Input[_builtins.bool]] = None) -> 'ObjectStorageBucket':
        """
        Get an existing ObjectStorageBucket resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_key: The access key to authenticate with. If not specified with the resource, its value can be
               * configured by `obj_access_key` in the provider configuration;
               * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        :param pulumi.Input[_builtins.str] acl: The Access Control Level of the bucket using a canned ACL string. See all ACL strings [in the Linode API v4 documentation](https://techdocs.akamai.com/linode-api/reference/post-object-storage-bucket).
        :param pulumi.Input[Union['ObjectStorageBucketCertArgs', 'ObjectStorageBucketCertArgsDict']] cert: The cert used by this Object Storage Bucket.
        :param pulumi.Input[_builtins.str] cluster: The cluster of the Linode Object Storage Bucket. This is deprecated in favor of `region` attribute.
               For example, `us-mia-1` cluster can be translated into `us-mia` region. Exactly one of `region` and `cluster` is required for creating a bucket.
        :param pulumi.Input[_builtins.bool] cors_enabled: If true, the bucket will have CORS enabled for all origins. Not supported by E2/E3 endpoints.
        :param pulumi.Input[_builtins.str] endpoint: The endpoint for the bucket used for s3 connections.
        :param pulumi.Input[_builtins.str] endpoint_type: The type of `s3_endpoint` available to the user in this region. See [Endpoint types](https://techdocs.akamai.com/cloud-computing/docs/object-storage#endpoint-type) for more information.
        :param pulumi.Input[_builtins.str] hostname: The hostname where this bucket can be accessed. This hostname can be accessed through a browser if the bucket is made public.
        :param pulumi.Input[_builtins.str] label: The label of the Linode Object Storage Bucket.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ObjectStorageBucketLifecycleRuleArgs', 'ObjectStorageBucketLifecycleRuleArgsDict']]]] lifecycle_rules: Lifecycle rules to be applied to the bucket.
        :param pulumi.Input[_builtins.str] region: The region of the Linode Object Storage Bucket. Exactly one of `region` and `cluster` is required for creating a bucket.
        :param pulumi.Input[_builtins.str] s3_endpoint: The user's s3 endpoint URL, based on the `endpoint_type` and `region`.
        :param pulumi.Input[_builtins.str] secret_key: The secret key to authenticate with. If not specified with the resource, its value can be
               * configured by `obj_secret_key` in the provider configuration;
               * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        :param pulumi.Input[_builtins.bool] versioning: Whether to enable versioning. Once you version-enable a bucket, it can never return to an unversioned state. You can, however, suspend versioning on that bucket. (Requires `access_key` and `secret_key`)
               
               * `lifecycle_rule` - (Optional) Lifecycle rules to be applied to the bucket. (Requires `access_key` and `secret_key`)
               
               * `cert` - (Optional) The bucket's TLS/SSL certificate.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ObjectStorageBucketState.__new__(_ObjectStorageBucketState)

        __props__.__dict__["access_key"] = access_key
        __props__.__dict__["acl"] = acl
        __props__.__dict__["cert"] = cert
        __props__.__dict__["cluster"] = cluster
        __props__.__dict__["cors_enabled"] = cors_enabled
        __props__.__dict__["endpoint"] = endpoint
        __props__.__dict__["endpoint_type"] = endpoint_type
        __props__.__dict__["hostname"] = hostname
        __props__.__dict__["label"] = label
        __props__.__dict__["lifecycle_rules"] = lifecycle_rules
        __props__.__dict__["region"] = region
        __props__.__dict__["s3_endpoint"] = s3_endpoint
        __props__.__dict__["secret_key"] = secret_key
        __props__.__dict__["versioning"] = versioning
        return ObjectStorageBucket(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The access key to authenticate with. If not specified with the resource, its value can be
        * configured by `obj_access_key` in the provider configuration;
        * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        """
        return pulumi.get(self, "access_key")

    @_builtins.property
    @pulumi.getter
    def acl(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The Access Control Level of the bucket using a canned ACL string. See all ACL strings [in the Linode API v4 documentation](https://techdocs.akamai.com/linode-api/reference/post-object-storage-bucket).
        """
        return pulumi.get(self, "acl")

    @_builtins.property
    @pulumi.getter
    def cert(self) -> pulumi.Output[Optional['outputs.ObjectStorageBucketCert']]:
        """
        The cert used by this Object Storage Bucket.
        """
        return pulumi.get(self, "cert")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""The cluster attribute has been deprecated, please consider switching to the region attribute. For example, a cluster value of `us-mia-1` can be translated to a region value of `us-mia`.""")
    def cluster(self) -> pulumi.Output[_builtins.str]:
        """
        The cluster of the Linode Object Storage Bucket. This is deprecated in favor of `region` attribute.
        For example, `us-mia-1` cluster can be translated into `us-mia` region. Exactly one of `region` and `cluster` is required for creating a bucket.
        """
        return pulumi.get(self, "cluster")

    @_builtins.property
    @pulumi.getter(name="corsEnabled")
    def cors_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        If true, the bucket will have CORS enabled for all origins. Not supported by E2/E3 endpoints.
        """
        return pulumi.get(self, "cors_enabled")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Use `s3_endpoint` instead""")
    def endpoint(self) -> pulumi.Output[_builtins.str]:
        """
        The endpoint for the bucket used for s3 connections.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of `s3_endpoint` available to the user in this region. See [Endpoint types](https://techdocs.akamai.com/cloud-computing/docs/object-storage#endpoint-type) for more information.
        """
        return pulumi.get(self, "endpoint_type")

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[_builtins.str]:
        """
        The hostname where this bucket can be accessed. This hostname can be accessed through a browser if the bucket is made public.
        """
        return pulumi.get(self, "hostname")

    @_builtins.property
    @pulumi.getter
    def label(self) -> pulumi.Output[_builtins.str]:
        """
        The label of the Linode Object Storage Bucket.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter(name="lifecycleRules")
    def lifecycle_rules(self) -> pulumi.Output[Optional[Sequence['outputs.ObjectStorageBucketLifecycleRule']]]:
        """
        Lifecycle rules to be applied to the bucket.
        """
        return pulumi.get(self, "lifecycle_rules")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region of the Linode Object Storage Bucket. Exactly one of `region` and `cluster` is required for creating a bucket.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="s3Endpoint")
    def s3_endpoint(self) -> pulumi.Output[_builtins.str]:
        """
        The user's s3 endpoint URL, based on the `endpoint_type` and `region`.
        """
        return pulumi.get(self, "s3_endpoint")

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The secret key to authenticate with. If not specified with the resource, its value can be
        * configured by `obj_secret_key` in the provider configuration;
        * or, generated implicitly at apply-time if `obj_use_temp_keys` at provider-level is set.
        """
        return pulumi.get(self, "secret_key")

    @_builtins.property
    @pulumi.getter
    def versioning(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to enable versioning. Once you version-enable a bucket, it can never return to an unversioned state. You can, however, suspend versioning on that bucket. (Requires `access_key` and `secret_key`)

        * `lifecycle_rule` - (Optional) Lifecycle rules to be applied to the bucket. (Requires `access_key` and `secret_key`)

        * `cert` - (Optional) The bucket's TLS/SSL certificate.
        """
        return pulumi.get(self, "versioning")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProfileResult',
    'AwaitableGetProfileResult',
    'get_profile',
    'get_profile_output',
]

@pulumi.output_type
class GetProfileResult:
    """
    A collection of values returned by getProfile.
    """
    def __init__(__self__, authorized_keys=None, email=None, email_notifications=None, id=None, ip_whitelist_enabled=None, lish_auth_method=None, referrals=None, restricted=None, timezone=None, two_factor_auth=None, username=None):
        if authorized_keys and not isinstance(authorized_keys, list):
            raise TypeError("Expected argument 'authorized_keys' to be a list")
        pulumi.set(__self__, "authorized_keys", authorized_keys)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if email_notifications and not isinstance(email_notifications, bool):
            raise TypeError("Expected argument 'email_notifications' to be a bool")
        pulumi.set(__self__, "email_notifications", email_notifications)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_whitelist_enabled and not isinstance(ip_whitelist_enabled, bool):
            raise TypeError("Expected argument 'ip_whitelist_enabled' to be a bool")
        pulumi.set(__self__, "ip_whitelist_enabled", ip_whitelist_enabled)
        if lish_auth_method and not isinstance(lish_auth_method, str):
            raise TypeError("Expected argument 'lish_auth_method' to be a str")
        pulumi.set(__self__, "lish_auth_method", lish_auth_method)
        if referrals and not isinstance(referrals, list):
            raise TypeError("Expected argument 'referrals' to be a list")
        pulumi.set(__self__, "referrals", referrals)
        if restricted and not isinstance(restricted, bool):
            raise TypeError("Expected argument 'restricted' to be a bool")
        pulumi.set(__self__, "restricted", restricted)
        if timezone and not isinstance(timezone, str):
            raise TypeError("Expected argument 'timezone' to be a str")
        pulumi.set(__self__, "timezone", timezone)
        if two_factor_auth and not isinstance(two_factor_auth, bool):
            raise TypeError("Expected argument 'two_factor_auth' to be a bool")
        pulumi.set(__self__, "two_factor_auth", two_factor_auth)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter(name="authorizedKeys")
    def authorized_keys(self) -> Sequence[_builtins.str]:
        """
        The list of SSH Keys authorized to use Lish for this user. This value is ignored if lish_auth_method is 'disabled'.
        """
        return pulumi.get(self, "authorized_keys")

    @_builtins.property
    @pulumi.getter
    def email(self) -> _builtins.str:
        """
        The profile email address. This address will be used for communication with Linode as necessary.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter(name="emailNotifications")
    def email_notifications(self) -> _builtins.bool:
        """
        If true, email notifications will be sent about account activity. If false, when false business-critical communications may still be sent through email.
        """
        return pulumi.get(self, "email_notifications")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ipWhitelistEnabled")
    def ip_whitelist_enabled(self) -> _builtins.bool:
        """
        If true, logins for the user will only be allowed from whitelisted IPs. This setting is currently deprecated, and cannot be enabled.
        """
        return pulumi.get(self, "ip_whitelist_enabled")

    @_builtins.property
    @pulumi.getter(name="lishAuthMethod")
    def lish_auth_method(self) -> _builtins.str:
        """
        The methods of authentication allowed when connecting via Lish. 'keys_only' is the most secure with the intent to use Lish, and 'disabled' is recommended for users that will not use Lish at all.
        """
        return pulumi.get(self, "lish_auth_method")

    @_builtins.property
    @pulumi.getter
    def referrals(self) -> Sequence['outputs.GetProfileReferralResult']:
        """
        Credit Card information associated with this Account.
        """
        return pulumi.get(self, "referrals")

    @_builtins.property
    @pulumi.getter
    def restricted(self) -> _builtins.bool:
        """
        If true, the user has restrictions on what can be accessed on the Account.
        """
        return pulumi.get(self, "restricted")

    @_builtins.property
    @pulumi.getter
    def timezone(self) -> _builtins.str:
        """
        The profile's preferred timezone. This is not used by the API, and is for the benefit of clients only. All times the API returns are in UTC.
        """
        return pulumi.get(self, "timezone")

    @_builtins.property
    @pulumi.getter(name="twoFactorAuth")
    def two_factor_auth(self) -> _builtins.bool:
        """
        If true, logins from untrusted computers will require Two Factor Authentication.
        """
        return pulumi.get(self, "two_factor_auth")

    @_builtins.property
    @pulumi.getter
    def username(self) -> _builtins.str:
        """
        The username for logging in to Linode services.
        """
        return pulumi.get(self, "username")


class AwaitableGetProfileResult(GetProfileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProfileResult(
            authorized_keys=self.authorized_keys,
            email=self.email,
            email_notifications=self.email_notifications,
            id=self.id,
            ip_whitelist_enabled=self.ip_whitelist_enabled,
            lish_auth_method=self.lish_auth_method,
            referrals=self.referrals,
            restricted=self.restricted,
            timezone=self.timezone,
            two_factor_auth=self.two_factor_auth,
            username=self.username)


def get_profile(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProfileResult:
    """
    Provides information about a Linode profile.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-profile).

    ## Example Usage

    The following example shows how one might use this data source to access profile details.

    ```python
    import pulumi
    import pulumi_linode as linode

    profile = linode.get_profile()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getProfile:getProfile', __args__, opts=opts, typ=GetProfileResult).value

    return AwaitableGetProfileResult(
        authorized_keys=pulumi.get(__ret__, 'authorized_keys'),
        email=pulumi.get(__ret__, 'email'),
        email_notifications=pulumi.get(__ret__, 'email_notifications'),
        id=pulumi.get(__ret__, 'id'),
        ip_whitelist_enabled=pulumi.get(__ret__, 'ip_whitelist_enabled'),
        lish_auth_method=pulumi.get(__ret__, 'lish_auth_method'),
        referrals=pulumi.get(__ret__, 'referrals'),
        restricted=pulumi.get(__ret__, 'restricted'),
        timezone=pulumi.get(__ret__, 'timezone'),
        two_factor_auth=pulumi.get(__ret__, 'two_factor_auth'),
        username=pulumi.get(__ret__, 'username'))
def get_profile_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProfileResult]:
    """
    Provides information about a Linode profile.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-profile).

    ## Example Usage

    The following example shows how one might use this data source to access profile details.

    ```python
    import pulumi
    import pulumi_linode as linode

    profile = linode.get_profile()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getProfile:getProfile', __args__, opts=opts, typ=GetProfileResult)
    return __ret__.apply(lambda __response__: GetProfileResult(
        authorized_keys=pulumi.get(__response__, 'authorized_keys'),
        email=pulumi.get(__response__, 'email'),
        email_notifications=pulumi.get(__response__, 'email_notifications'),
        id=pulumi.get(__response__, 'id'),
        ip_whitelist_enabled=pulumi.get(__response__, 'ip_whitelist_enabled'),
        lish_auth_method=pulumi.get(__response__, 'lish_auth_method'),
        referrals=pulumi.get(__response__, 'referrals'),
        restricted=pulumi.get(__response__, 'restricted'),
        timezone=pulumi.get(__response__, 'timezone'),
        two_factor_auth=pulumi.get(__response__, 'two_factor_auth'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetMaintenancePoliciesResult',
    'AwaitableGetMaintenancePoliciesResult',
    'get_maintenance_policies',
    'get_maintenance_policies_output',
]

@pulumi.output_type
class GetMaintenancePoliciesResult:
    """
    A collection of values returned by getMaintenancePolicies.
    """
    def __init__(__self__, filters=None, id=None, maintenance_policies=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if maintenance_policies and not isinstance(maintenance_policies, list):
            raise TypeError("Expected argument 'maintenance_policies' to be a list")
        pulumi.set(__self__, "maintenance_policies", maintenance_policies)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetMaintenancePoliciesFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="maintenancePolicies")
    def maintenance_policies(self) -> Optional[Sequence['outputs.GetMaintenancePoliciesMaintenancePolicyResult']]:
        return pulumi.get(self, "maintenance_policies")


class AwaitableGetMaintenancePoliciesResult(GetMaintenancePoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMaintenancePoliciesResult(
            filters=self.filters,
            id=self.id,
            maintenance_policies=self.maintenance_policies)


def get_maintenance_policies(filters: Optional[Sequence[Union['GetMaintenancePoliciesFilterArgs', 'GetMaintenancePoliciesFilterArgsDict']]] = None,
                             maintenance_policies: Optional[Sequence[Union['GetMaintenancePoliciesMaintenancePolicyArgs', 'GetMaintenancePoliciesMaintenancePolicyArgsDict']]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMaintenancePoliciesResult:
    """
    Provides details about the Maintenance Policies available to apply to Accounts and Instances.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-maintenance-policies). (**Note: v4beta only.**)

    ## Example Usage

    The following example shows how one might use this data source to access information about Maintenance Policies:

    ```python
    import pulumi
    import pulumi_linode as linode

    example = linode.get_maintenance_policies()
    pulumi.export("exampleOutput", example)
    ```

    The following example shows how one might use this data source to access information about Maintenance Policies with a certain slug:
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['maintenancePolicies'] = maintenance_policies
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getMaintenancePolicies:getMaintenancePolicies', __args__, opts=opts, typ=GetMaintenancePoliciesResult).value

    return AwaitableGetMaintenancePoliciesResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        maintenance_policies=pulumi.get(__ret__, 'maintenance_policies'))
def get_maintenance_policies_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetMaintenancePoliciesFilterArgs', 'GetMaintenancePoliciesFilterArgsDict']]]]] = None,
                                    maintenance_policies: Optional[pulumi.Input[Optional[Sequence[Union['GetMaintenancePoliciesMaintenancePolicyArgs', 'GetMaintenancePoliciesMaintenancePolicyArgsDict']]]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMaintenancePoliciesResult]:
    """
    Provides details about the Maintenance Policies available to apply to Accounts and Instances.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-maintenance-policies). (**Note: v4beta only.**)

    ## Example Usage

    The following example shows how one might use this data source to access information about Maintenance Policies:

    ```python
    import pulumi
    import pulumi_linode as linode

    example = linode.get_maintenance_policies()
    pulumi.export("exampleOutput", example)
    ```

    The following example shows how one might use this data source to access information about Maintenance Policies with a certain slug:
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['maintenancePolicies'] = maintenance_policies
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getMaintenancePolicies:getMaintenancePolicies', __args__, opts=opts, typ=GetMaintenancePoliciesResult)
    return __ret__.apply(lambda __response__: GetMaintenancePoliciesResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        maintenance_policies=pulumi.get(__response__, 'maintenance_policies')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetNetworkingIpsResult',
    'AwaitableGetNetworkingIpsResult',
    'get_networking_ips',
    'get_networking_ips_output',
]

@pulumi.output_type
class GetNetworkingIpsResult:
    """
    A collection of values returned by getNetworkingIps.
    """
    def __init__(__self__, filters=None, id=None, ip_addresses=None, order=None, order_by=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_addresses and not isinstance(ip_addresses, list):
            raise TypeError("Expected argument 'ip_addresses' to be a list")
        pulumi.set(__self__, "ip_addresses", ip_addresses)
        if order and not isinstance(order, str):
            raise TypeError("Expected argument 'order' to be a str")
        pulumi.set(__self__, "order", order)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetNetworkingIpsFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ipAddresses")
    def ip_addresses(self) -> Optional[Sequence['outputs.GetNetworkingIpsIpAddressResult']]:
        return pulumi.get(self, "ip_addresses")

    @_builtins.property
    @pulumi.getter
    def order(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order_by")


class AwaitableGetNetworkingIpsResult(GetNetworkingIpsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkingIpsResult(
            filters=self.filters,
            id=self.id,
            ip_addresses=self.ip_addresses,
            order=self.order,
            order_by=self.order_by)


def get_networking_ips(filters: Optional[Sequence[Union['GetNetworkingIpsFilterArgs', 'GetNetworkingIpsFilterArgsDict']]] = None,
                       ip_addresses: Optional[Sequence[Union['GetNetworkingIpsIpAddressArgs', 'GetNetworkingIpsIpAddressArgsDict']]] = None,
                       order: Optional[_builtins.str] = None,
                       order_by: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkingIpsResult:
    """
    Provides information about all IP addresses associated with the current Linode account, including both assigned and unassigned reserved IP addresses.

    ## Example Usage

    Retrieve all IPs under the current account:

    ```python
    import pulumi
    import pulumi_linode as linode

    all = linode.get_networking_ips()
    ```

    Retrieve all IPs under the current account in a specific region:

    ```python
    import pulumi
    import pulumi_linode as linode

    filtered = linode.get_networking_ips(filters=[{
        "name": "region",
        "values": ["us-mia"],
    }])
    ```

    ## Filterable Fields

    * `address`

    * `gateway`

    * `subnet_mask`

    * `prefix`

    * `type`

    * `public`

    * `rdns`

    * `linode_id`

    * `region`

    * `reserved`


    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['ipAddresses'] = ip_addresses
    __args__['order'] = order
    __args__['orderBy'] = order_by
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getNetworkingIps:getNetworkingIps', __args__, opts=opts, typ=GetNetworkingIpsResult).value

    return AwaitableGetNetworkingIpsResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        ip_addresses=pulumi.get(__ret__, 'ip_addresses'),
        order=pulumi.get(__ret__, 'order'),
        order_by=pulumi.get(__ret__, 'order_by'))
def get_networking_ips_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetNetworkingIpsFilterArgs', 'GetNetworkingIpsFilterArgsDict']]]]] = None,
                              ip_addresses: Optional[pulumi.Input[Optional[Sequence[Union['GetNetworkingIpsIpAddressArgs', 'GetNetworkingIpsIpAddressArgsDict']]]]] = None,
                              order: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkingIpsResult]:
    """
    Provides information about all IP addresses associated with the current Linode account, including both assigned and unassigned reserved IP addresses.

    ## Example Usage

    Retrieve all IPs under the current account:

    ```python
    import pulumi
    import pulumi_linode as linode

    all = linode.get_networking_ips()
    ```

    Retrieve all IPs under the current account in a specific region:

    ```python
    import pulumi
    import pulumi_linode as linode

    filtered = linode.get_networking_ips(filters=[{
        "name": "region",
        "values": ["us-mia"],
    }])
    ```

    ## Filterable Fields

    * `address`

    * `gateway`

    * `subnet_mask`

    * `prefix`

    * `type`

    * `public`

    * `rdns`

    * `linode_id`

    * `region`

    * `reserved`


    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['ipAddresses'] = ip_addresses
    __args__['order'] = order
    __args__['orderBy'] = order_by
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getNetworkingIps:getNetworkingIps', __args__, opts=opts, typ=GetNetworkingIpsResult)
    return __ret__.apply(lambda __response__: GetNetworkingIpsResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        ip_addresses=pulumi.get(__response__, 'ip_addresses'),
        order=pulumi.get(__response__, 'order'),
        order_by=pulumi.get(__response__, 'order_by')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPlacementGroupsResult',
    'AwaitableGetPlacementGroupsResult',
    'get_placement_groups',
    'get_placement_groups_output',
]

@pulumi.output_type
class GetPlacementGroupsResult:
    """
    A collection of values returned by getPlacementGroups.
    """
    def __init__(__self__, filters=None, id=None, order=None, order_by=None, placement_groups=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if order and not isinstance(order, str):
            raise TypeError("Expected argument 'order' to be a str")
        pulumi.set(__self__, "order", order)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)
        if placement_groups and not isinstance(placement_groups, list):
            raise TypeError("Expected argument 'placement_groups' to be a list")
        pulumi.set(__self__, "placement_groups", placement_groups)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetPlacementGroupsFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def order(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order_by")

    @_builtins.property
    @pulumi.getter(name="placementGroups")
    def placement_groups(self) -> Optional[Sequence['outputs.GetPlacementGroupsPlacementGroupResult']]:
        return pulumi.get(self, "placement_groups")


class AwaitableGetPlacementGroupsResult(GetPlacementGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPlacementGroupsResult(
            filters=self.filters,
            id=self.id,
            order=self.order,
            order_by=self.order_by,
            placement_groups=self.placement_groups)


def get_placement_groups(filters: Optional[Sequence[Union['GetPlacementGroupsFilterArgs', 'GetPlacementGroupsFilterArgsDict']]] = None,
                         order: Optional[_builtins.str] = None,
                         order_by: Optional[_builtins.str] = None,
                         placement_groups: Optional[Sequence[Union['GetPlacementGroupsPlacementGroupArgs', 'GetPlacementGroupsPlacementGroupArgsDict']]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPlacementGroupsResult:
    """
    Provides information about a list of Linode Placement Groups that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-placement-groups).

    ## Example Usage

    The following example shows how one might use this data source to list Placement Groups.

    ```python
    import pulumi
    import pulumi_linode as linode

    all = linode.get_placement_groups()
    filtered = linode.get_placement_groups(filters=[{
        "name": "label",
        "values": ["my-label"],
    }])
    pulumi.export("all-pgs", all.placement_groups)
    pulumi.export("filtered-pgs", filtered.placement_groups)
    ```

    ## Filterable Fields

    * `id`

    * `label`

    * `region`

    * `placement_group_type`

    * `placement_group_policy`

    * `is_compliant`
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['order'] = order
    __args__['orderBy'] = order_by
    __args__['placementGroups'] = placement_groups
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getPlacementGroups:getPlacementGroups', __args__, opts=opts, typ=GetPlacementGroupsResult).value

    return AwaitableGetPlacementGroupsResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        order=pulumi.get(__ret__, 'order'),
        order_by=pulumi.get(__ret__, 'order_by'),
        placement_groups=pulumi.get(__ret__, 'placement_groups'))
def get_placement_groups_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetPlacementGroupsFilterArgs', 'GetPlacementGroupsFilterArgsDict']]]]] = None,
                                order: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                placement_groups: Optional[pulumi.Input[Optional[Sequence[Union['GetPlacementGroupsPlacementGroupArgs', 'GetPlacementGroupsPlacementGroupArgsDict']]]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPlacementGroupsResult]:
    """
    Provides information about a list of Linode Placement Groups that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-placement-groups).

    ## Example Usage

    The following example shows how one might use this data source to list Placement Groups.

    ```python
    import pulumi
    import pulumi_linode as linode

    all = linode.get_placement_groups()
    filtered = linode.get_placement_groups(filters=[{
        "name": "label",
        "values": ["my-label"],
    }])
    pulumi.export("all-pgs", all.placement_groups)
    pulumi.export("filtered-pgs", filtered.placement_groups)
    ```

    ## Filterable Fields

    * `id`

    * `label`

    * `region`

    * `placement_group_type`

    * `placement_group_policy`

    * `is_compliant`
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['order'] = order
    __args__['orderBy'] = order_by
    __args__['placementGroups'] = placement_groups
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getPlacementGroups:getPlacementGroups', __args__, opts=opts, typ=GetPlacementGroupsResult)
    return __ret__.apply(lambda __response__: GetPlacementGroupsResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        order=pulumi.get(__response__, 'order'),
        order_by=pulumi.get(__response__, 'order_by'),
        placement_groups=pulumi.get(__response__, 'placement_groups')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetNodebalancerVpcsResult',
    'AwaitableGetNodebalancerVpcsResult',
    'get_nodebalancer_vpcs',
    'get_nodebalancer_vpcs_output',
]

@pulumi.output_type
class GetNodebalancerVpcsResult:
    """
    A collection of values returned by getNodebalancerVpcs.
    """
    def __init__(__self__, filters=None, id=None, nodebalancer_id=None, order=None, order_by=None, vpc_configs=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if nodebalancer_id and not isinstance(nodebalancer_id, int):
            raise TypeError("Expected argument 'nodebalancer_id' to be a int")
        pulumi.set(__self__, "nodebalancer_id", nodebalancer_id)
        if order and not isinstance(order, str):
            raise TypeError("Expected argument 'order' to be a str")
        pulumi.set(__self__, "order", order)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)
        if vpc_configs and not isinstance(vpc_configs, list):
            raise TypeError("Expected argument 'vpc_configs' to be a list")
        pulumi.set(__self__, "vpc_configs", vpc_configs)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetNodebalancerVpcsFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the VPC configuration.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="nodebalancerId")
    def nodebalancer_id(self) -> _builtins.int:
        """
        The ID of the parent NodeBalancer for this VPC configuration.
        """
        return pulumi.get(self, "nodebalancer_id")

    @_builtins.property
    @pulumi.getter
    def order(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order_by")

    @_builtins.property
    @pulumi.getter(name="vpcConfigs")
    def vpc_configs(self) -> Sequence['outputs.GetNodebalancerVpcsVpcConfigResult']:
        return pulumi.get(self, "vpc_configs")


class AwaitableGetNodebalancerVpcsResult(GetNodebalancerVpcsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNodebalancerVpcsResult(
            filters=self.filters,
            id=self.id,
            nodebalancer_id=self.nodebalancer_id,
            order=self.order,
            order_by=self.order_by,
            vpc_configs=self.vpc_configs)


def get_nodebalancer_vpcs(filters: Optional[Sequence[Union['GetNodebalancerVpcsFilterArgs', 'GetNodebalancerVpcsFilterArgsDict']]] = None,
                          nodebalancer_id: Optional[_builtins.int] = None,
                          order: Optional[_builtins.str] = None,
                          order_by: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNodebalancerVpcsResult:
    """
    > **Limited Availability** VPC-attached NodeBalancers may not currently be available to all users and may require the `api_version` provider argument must be set to `v4beta`.

    Provides information about Linode NodeBalancers VPC configurations that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-node-balancers).

    ## Example Usage

    Retrieve all VPC configurations under a NodeBalancer:

    ```python
    import pulumi
    import pulumi_linode as linode

    vpc_configs = linode.get_nodebalancer_vpcs(nodebalancer_id=12345)
    ```

    Retrieve all VPC configurations under a NodeBalancer with an IPv4 range of "10.0.0.4/30":

    ```python
    import pulumi
    import pulumi_linode as linode

    vpc_configs = linode.get_nodebalancer_vpcs(nodebalancer_id=12345,
        filters=[{
            "name": "ipv4_range",
            "values": ["10.0.0.4/30"],
        }])
    ```

    ## Filterable Fields

    * `id`

    * `ipv4_range`

    * `nodebalancer_id`

    * `subnet_id`

    * `vpc_id`


    :param _builtins.int nodebalancer_id: The ID of the NodeBalancer to list VPC configurations for.
           
           * `filter` - (Optional) A set of filters used to select VPC configurations that meet certain requirements.
    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['nodebalancerId'] = nodebalancer_id
    __args__['order'] = order
    __args__['orderBy'] = order_by
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getNodebalancerVpcs:getNodebalancerVpcs', __args__, opts=opts, typ=GetNodebalancerVpcsResult).value

    return AwaitableGetNodebalancerVpcsResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        nodebalancer_id=pulumi.get(__ret__, 'nodebalancer_id'),
        order=pulumi.get(__ret__, 'order'),
        order_by=pulumi.get(__ret__, 'order_by'),
        vpc_configs=pulumi.get(__ret__, 'vpc_configs'))
def get_nodebalancer_vpcs_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetNodebalancerVpcsFilterArgs', 'GetNodebalancerVpcsFilterArgsDict']]]]] = None,
                                 nodebalancer_id: Optional[pulumi.Input[_builtins.int]] = None,
                                 order: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNodebalancerVpcsResult]:
    """
    > **Limited Availability** VPC-attached NodeBalancers may not currently be available to all users and may require the `api_version` provider argument must be set to `v4beta`.

    Provides information about Linode NodeBalancers VPC configurations that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-node-balancers).

    ## Example Usage

    Retrieve all VPC configurations under a NodeBalancer:

    ```python
    import pulumi
    import pulumi_linode as linode

    vpc_configs = linode.get_nodebalancer_vpcs(nodebalancer_id=12345)
    ```

    Retrieve all VPC configurations under a NodeBalancer with an IPv4 range of "10.0.0.4/30":

    ```python
    import pulumi
    import pulumi_linode as linode

    vpc_configs = linode.get_nodebalancer_vpcs(nodebalancer_id=12345,
        filters=[{
            "name": "ipv4_range",
            "values": ["10.0.0.4/30"],
        }])
    ```

    ## Filterable Fields

    * `id`

    * `ipv4_range`

    * `nodebalancer_id`

    * `subnet_id`

    * `vpc_id`


    :param _builtins.int nodebalancer_id: The ID of the NodeBalancer to list VPC configurations for.
           
           * `filter` - (Optional) A set of filters used to select VPC configurations that meet certain requirements.
    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['nodebalancerId'] = nodebalancer_id
    __args__['order'] = order
    __args__['orderBy'] = order_by
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getNodebalancerVpcs:getNodebalancerVpcs', __args__, opts=opts, typ=GetNodebalancerVpcsResult)
    return __ret__.apply(lambda __response__: GetNodebalancerVpcsResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        nodebalancer_id=pulumi.get(__response__, 'nodebalancer_id'),
        order=pulumi.get(__response__, 'order'),
        order_by=pulumi.get(__response__, 'order_by'),
        vpc_configs=pulumi.get(__response__, 'vpc_configs')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetImagesResult',
    'AwaitableGetImagesResult',
    'get_images',
    'get_images_output',
]

@pulumi.output_type
class GetImagesResult:
    """
    A collection of values returned by getImages.
    """
    def __init__(__self__, filters=None, id=None, images=None, latest=None, order=None, order_by=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if images and not isinstance(images, list):
            raise TypeError("Expected argument 'images' to be a list")
        pulumi.set(__self__, "images", images)
        if latest and not isinstance(latest, bool):
            raise TypeError("Expected argument 'latest' to be a bool")
        pulumi.set(__self__, "latest", latest)
        if order and not isinstance(order, str):
            raise TypeError("Expected argument 'order' to be a str")
        pulumi.set(__self__, "order", order)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetImagesFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique ID of this Image.  The ID of private images begin with `private/` followed by the numeric identifier of the private image, for example `private/12345`.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def images(self) -> Optional[Sequence['outputs.GetImagesImageResult']]:
        return pulumi.get(self, "images")

    @_builtins.property
    @pulumi.getter
    def latest(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "latest")

    @_builtins.property
    @pulumi.getter
    def order(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order_by")


class AwaitableGetImagesResult(GetImagesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetImagesResult(
            filters=self.filters,
            id=self.id,
            images=self.images,
            latest=self.latest,
            order=self.order,
            order_by=self.order_by)


def get_images(filters: Optional[Sequence[Union['GetImagesFilterArgs', 'GetImagesFilterArgsDict']]] = None,
               images: Optional[Sequence[Union['GetImagesImageArgs', 'GetImagesImageArgsDict']]] = None,
               latest: Optional[_builtins.bool] = None,
               order: Optional[_builtins.str] = None,
               order_by: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetImagesResult:
    """
    Provides information about Linode images that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-images).

    ## Example Usage

    Get information about all Linode images with a certain label and visibility:

    ```python
    import pulumi
    import pulumi_linode as linode

    specific_images = linode.get_images(filters=[
        {
            "name": "label",
            "values": ["Debian 12"],
        },
        {
            "name": "is_public",
            "values": ["true"],
        },
    ])
    pulumi.export("imageId", specific_images.images[0].id)
    ```

    Get information about all Linode images associated with the current token:

    ```python
    import pulumi
    import pulumi_linode as linode

    all_images = linode.get_images()
    pulumi.export("imageIds", [__item.id for __item in all_images.images])
    ```

    ## Filterable Fields

    * `created_by`

    * `deprecated`

    * `description`

    * `id`

    * `is_public`

    * `label`

    * `size`

    * `status`

    * `vendor`

    * `tags`


    :param _builtins.bool latest: If true, only the latest image will be returned. Images without a valid `created` field are not included in the result.
           
           * `filter` - (Optional) A set of filters used to select Linode images that meet certain requirements.
    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['images'] = images
    __args__['latest'] = latest
    __args__['order'] = order
    __args__['orderBy'] = order_by
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getImages:getImages', __args__, opts=opts, typ=GetImagesResult).value

    return AwaitableGetImagesResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        images=pulumi.get(__ret__, 'images'),
        latest=pulumi.get(__ret__, 'latest'),
        order=pulumi.get(__ret__, 'order'),
        order_by=pulumi.get(__ret__, 'order_by'))
def get_images_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetImagesFilterArgs', 'GetImagesFilterArgsDict']]]]] = None,
                      images: Optional[pulumi.Input[Optional[Sequence[Union['GetImagesImageArgs', 'GetImagesImageArgsDict']]]]] = None,
                      latest: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                      order: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetImagesResult]:
    """
    Provides information about Linode images that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-images).

    ## Example Usage

    Get information about all Linode images with a certain label and visibility:

    ```python
    import pulumi
    import pulumi_linode as linode

    specific_images = linode.get_images(filters=[
        {
            "name": "label",
            "values": ["Debian 12"],
        },
        {
            "name": "is_public",
            "values": ["true"],
        },
    ])
    pulumi.export("imageId", specific_images.images[0].id)
    ```

    Get information about all Linode images associated with the current token:

    ```python
    import pulumi
    import pulumi_linode as linode

    all_images = linode.get_images()
    pulumi.export("imageIds", [__item.id for __item in all_images.images])
    ```

    ## Filterable Fields

    * `created_by`

    * `deprecated`

    * `description`

    * `id`

    * `is_public`

    * `label`

    * `size`

    * `status`

    * `vendor`

    * `tags`


    :param _builtins.bool latest: If true, only the latest image will be returned. Images without a valid `created` field are not included in the result.
           
           * `filter` - (Optional) A set of filters used to select Linode images that meet certain requirements.
    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['images'] = images
    __args__['latest'] = latest
    __args__['order'] = order
    __args__['orderBy'] = order_by
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getImages:getImages', __args__, opts=opts, typ=GetImagesResult)
    return __ret__.apply(lambda __response__: GetImagesResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        images=pulumi.get(__response__, 'images'),
        latest=pulumi.get(__response__, 'latest'),
        order=pulumi.get(__response__, 'order'),
        order_by=pulumi.get(__response__, 'order_by')))
